@@ -67,11 +67,17 @@ sub uniq_files {
     return @output;
 }
 
+# Yes, this isn't working right for undef. That shouldn't be a path element
+# anyway but there are bugs in Env.pm this is working around.
 sub firsts_not_in_second(\@ \@) {
     good_args(@_ == 2);
     my($aref, $bref) = @_;
-    my %seen = map { $_ => 1 } grep {defined} @$bref;
-    return grep { ! $seen{$_} } @$aref;
+
+    # worst case
+    local $SIG{__WARN__} = sub {};
+
+    my %seen = map { $_ => 1 }  grep {defined} @$bref;
+    return grep { ! $seen{$_} } grep {defined} @$aref;
 }
 
 sub somedir_map(&@) {
